==> hibernate-envers-4.1.4.Final-sources.jar: org/hibernate/envers/entities/mapper/relation/lazy/initializor/SortedSetCollectionInitializor.java <==
/*
 * Hibernate, Relational Persistence for Idiomatic Java
 *
 * Copyright (c) 2008, Red Hat Middleware LLC or third-party contributors as
 * indicated by the @author tags or express copyright attribution
 * statements applied by the authors.  All third-party contributions are
 * distributed under license by Red Hat Middleware LLC.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution; if not, write to:
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA  02110-1301  USA
 */
package org.hibernate.envers.entities.mapper.relation.lazy.initializor;

import java.lang.reflect.InvocationTargetException;
import java.util.Comparator;
import java.util.SortedSet;

import org.hibernate.envers.configuration.AuditConfiguration;
import org.hibernate.envers.entities.mapper.relation.MiddleComponentData;
import org.hibernate.envers.entities.mapper.relation.query.RelationQueryGenerator;
import org.hibernate.envers.exception.AuditException;
import org.hibernate.envers.reader.AuditReaderImplementor;

/**
 * Initializes SortedSet collection with proper Comparator
 *
 * @author Michal Skowronek (mskowr at o2 dot pl)
 */
public class SortedSetCollectionInitializor extends BasicCollectionInitializor<SortedSet> {
	private final Comparator comparator;

	public SortedSetCollectionInitializor(AuditConfiguration verCfg, AuditReaderImplementor versionsReader, RelationQueryGenerator queryGenerator, Object primaryKey, Number revision, Class<? extends SortedSet> collectionClass, MiddleComponentData elementComponentData, Comparator comparator) {
		super(verCfg, versionsReader, queryGenerator, primaryKey, revision, collectionClass, elementComponentData);
		this.comparator = comparator;
	}

	@Override
	protected SortedSet initializeCollection(int size) {
		if (comparator == null) {
			return super.initializeCollection(size);
		}
		try {
			return collectionClass.getConstructor(Comparator.class).newInstance(comparator);
		} catch (InstantiationException e) {
			throw new AuditException(e);
		} catch (IllegalAccessException e) {
			throw new AuditException(e);
		} catch (NoSuchMethodException e) {
			throw new AuditException(e);
		} catch (InvocationTargetException e) {
			throw new AuditException(e);
		}
	}
}

==> hibernate-envers-4.2.14.Final-sources.jar: org/hibernate/envers/entities/mapper/relation/lazy/initializor/SortedSetCollectionInitializor.java <==
/*
 * Hibernate, Relational Persistence for Idiomatic Java
 *
 * Copyright (c) 2008, Red Hat Middleware LLC or third-party contributors as
 * indicated by the @author tags or express copyright attribution
 * statements applied by the authors.  All third-party contributions are
 * distributed under license by Red Hat Middleware LLC.
 *
 * This copyrighted material is made available to anyone wishing to use, modify,
 * copy, or redistribute it subject to the terms and conditions of the GNU
 * Lesser General Public License, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 * for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this distribution; if not, write to:
 * Free Software Foundation, Inc.
 * 51 Franklin Street, Fifth Floor
 * Boston, MA  02110-1301  USA
 */
package org.hibernate.envers.entities.mapper.relation.lazy.initializor;

import java.lang.reflect.InvocationTargetException;
import java.util.Comparator;
import java.util.SortedSet;

import org.hibernate.envers.configuration.AuditConfiguration;
import org.hibernate.envers.entities.mapper.relation.MiddleComponentData;
import org.hibernate.envers.entities.mapper.relation.query.RelationQueryGenerator;
import org.hibernate.envers.exception.AuditException;
import org.hibernate.envers.reader.AuditReaderImplementor;

/**
 * Initializes SortedSet collection with proper Comparator
 *
 * @author Michal Skowronek (mskowr at o2 dot pl)
 */
public class SortedSetCollectionInitializor extends BasicCollectionInitializor<SortedSet> {
	private final Comparator comparator;

	public SortedSetCollectionInitializor(AuditConfiguration verCfg, AuditReaderImplementor versionsReader,
										  RelationQueryGenerator queryGenerator, Object primaryKey, Number revision, boolean removed,
										  Class<? extends SortedSet> collectionClass, MiddleComponentData elementComponentData,
										  Comparator comparator) {
		super(verCfg, versionsReader, queryGenerator, primaryKey, revision, removed, collectionClass, elementComponentData);
		this.comparator = comparator;
	}

	@Override
	protected SortedSet initializeCollection(int size) {
		if (comparator == null) {
			return super.initializeCollection(size);
		}
		try {
			return collectionClass.getConstructor(Comparator.class).newInstance(comparator);
		} catch (InstantiationException e) {
			throw new AuditException(e);
		} catch (IllegalAccessException e) {
			throw new AuditException(e);
		} catch (NoSuchMethodException e) {
			throw new AuditException(e);
		} catch (InvocationTargetException e) {
			throw new AuditException(e);
		}
	}
}
